@@ -123,6 +123,9 @@ const bool ConfigItems::load( const bool restore )
     ref_prefix_space = cf.get_option_int( "ref_prefix_space", CONF_REF_PREFIX_SPACE, 0, 16 );
     for( int i = 0; i < ref_prefix_space; ++i ) ref_prefix_space_str += " ";
 
+    // レスにアスキーアートがあると判定する正規表現
+    regex_res_aa = cf.get_option_str( "regex_res_aa", CONF_REGEX_RES_AA );
+
     // キャッシュのルートディレクトリ(旧バージョンとの互換のため残している)
     path_cacheroot = cf.get_option_str( "path_cacheroot", CONF_PATH_CACHEROOT );
 
@@ -176,6 +179,9 @@ const bool ConfigItems::load( const bool restore )
     cookie_hap = cf.get_option_str( "cookie_hap", CONF_COOKIE_HAP );
     cookie_hap_bbspink = cf.get_option_str( "cookie_hap_bbspink", CONF_COOKIE_HAP_BBSPINK );
 
+    // 2chの過去ログ取得時にofflaw2を使用する
+    use_offlaw2_2ch = cf.get_option_bool( "use_offlaw2_2ch", CONF_USE_OFFLAW2_2CH );
+
     // ブラウザ設定ダイアログのコンボボックスの番号
     browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
@@ -216,6 +222,9 @@ const bool ConfigItems::load( const bool restore )
     embimg_width = cf.get_option_int( "embimg_width", CONF_EMBIMG_WIDTH, 16, 8192 );
     embimg_height = cf.get_option_int( "embimg_height", CONF_EMBIMG_HEIGHT, 16, 8192 );
 
+    // 埋め込み画像ビューを閉じたときにタブも閉じる
+    hide_imagetab = cf.get_option_bool( "hide_imagetab", CONF_HIDE_IMAGETAB );
+
     // 画像ビューでdeleteを押したときに確認ダイアログを表示する
     show_delimgdiag = cf.get_option_bool( "show_delimgdiag", CONF_SHOW_DELIMGDIAG );
 
@@ -297,6 +306,9 @@ const bool ConfigItems::load( const bool restore )
     // カテゴリを開いたときにツリービューをスクロールする
     scroll_tree = cf.get_option_bool( "scroll_tree", CONF_SCROLL_TREE );
 
+    // ツリービューの選択を表示中のビューと同期する
+    select_item_sync = cf.get_option_int( "select_item_sync", CONF_SELECT_ITEM_SYNC, 0, 2 );
+
     // 各ビューと枠との間の余白
     view_margin = cf.get_option_int( "view_margin", CONF_VIEW_MARGIN, 0, 64 );
 
@@ -429,6 +441,9 @@ const bool ConfigItems::load( const bool restore )
     instruct_tglimg = cf.get_option_bool( "instruct_tglimg", CONF_INSTRUCT_TGLIMG );
     instruct_tglimg_end = false;
 
+    // スレビューでdeleteを押したときに確認ダイアログを表示する
+    show_delartdiag = cf.get_option_bool( "show_delartdiag", CONF_SHOW_DELARTDIAG );
+
     // 下線位置
     adjust_underline_pos = cf.get_option_double( "adjust_underline_pos", ( double )CONF_ADJUST_UNDERLINE_POS, ( double )0, ( double )64 );
 
@@ -467,6 +482,18 @@ const bool ConfigItems::load( const bool restore )
     // タブにアイコンを表示するか
     show_tab_icon = cf.get_option_bool( "show_tab_icon", CONF_SHOW_TAB_ICON );
 
+    // タブ上でマウスホイールを回転してタブを切り替える
+    switchtab_wheel = cf.get_option_bool( "switchtab_wheel", CONF_SWITCHTAB_WHEEL );
+
+    // 他のビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    newtab_pos = cf.get_option_int( "newtab_pos", CONF_NEWTAB_POS, 0, 2 );
+
+    // ツリービューで選択したビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    opentab_pos = cf.get_option_int( "opentab_pos", CONF_OPENTAB_POS, 0, 2 );
+
+    // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え -1:2.8.5以前の動作 )
+    boardnexttab_pos = cf.get_option_int( "boardnexttab_pos", CONF_BOARDNEXTTAB_POS, -1, 2 );
+
     // スレビューに書き込みマークを表示するか
     show_post_mark = cf.get_option_bool( "show_post_mark", CONF_SHOW_POST_MARK );
 
@@ -652,6 +679,7 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "fontname_main", fontname[ FONT_MAIN ] );
     cf.update( "fontname_popup", fontname[ FONT_POPUP ] );
+    cf.update( "fontname_aa", fontname[ FONT_AA ] );
     cf.update( "fontname_bbs", fontname[ FONT_BBS ] );
     cf.update( "fontname_board", fontname[ FONT_BOARD ] );
     cf.update( "fontname_message", fontname[ FONT_MESSAGE ] );
@@ -659,6 +687,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "ref_prefix", ref_prefix );
     cf.update( "ref_prefix_space", ref_prefix_space );
 
+    cf.update( "regex_res_aa", regex_res_aa );
+
     cf.update( "path_cacheroot", path_cacheroot );
 
     cf.update( "agent_for2ch", agent_for2ch );
@@ -701,6 +731,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cookie_hap", cookie_hap );
     cf.update( "cookie_hap_bbspink", cookie_hap_bbspink );
 
+    cf.update( "use_offlaw2_2ch", use_offlaw2_2ch );
+
     cf.update( "command_openurl", command_openurl );
     cf.update( "browsercombo_id", browsercombo_id );
 
@@ -719,6 +751,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "show_ssspicon", show_ssspicon );
     cf.update( "embimg_width", embimg_width );
     cf.update( "embimg_height", embimg_height );
+    cf.update( "hide_imagetab", hide_imagetab );
     cf.update( "show_delimgdiag", show_delimgdiag );
     cf.update( "use_mosaic", use_mosaic );
     cf.update( "mosaic_size", mosaic_size );
@@ -737,6 +770,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_char_selection", str_color[ COLOR_CHAR_SELECTION ] );
     cf.update( "cl_char_highlight", str_color[ COLOR_CHAR_HIGHLIGHT ] );
     cf.update( "cl_char_link", str_color[ COLOR_CHAR_LINK ] );
+    cf.update( "cl_char_link_id_low", str_color[ COLOR_CHAR_LINK_ID_LOW ] );
+    cf.update( "cl_char_link_id_high", str_color[ COLOR_CHAR_LINK_ID_HIGH ] );
+    cf.update( "cl_char_link_res", str_color[ COLOR_CHAR_LINK_RES ] );
     cf.update( "cl_char_link_low", str_color[ COLOR_CHAR_LINK_LOW ] );
     cf.update( "cl_char_link_high", str_color[ COLOR_CHAR_LINK_HIGH ] );
     cf.update( "cl_char_message", str_color[ COLOR_CHAR_MESSAGE ] );
@@ -771,6 +807,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "tree_level_indent", tree_level_indent );
 
     cf.update( "scroll_tree", scroll_tree );
+    cf.update( "select_item_sync", select_item_sync );
 
     cf.update( "view_margin", view_margin );
 
@@ -822,6 +859,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "instruct_popup", instruct_popup );
     cf.update( "instruct_tglart", instruct_tglart );
     cf.update( "instruct_tglimg", instruct_tglimg );
+    cf.update( "show_delartdiag", show_delartdiag );
 
     cf.update( "adjust_underline_pos", adjust_underline_pos );
     cf.update( "adjust_line_space", adjust_line_space );
@@ -843,6 +881,14 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "tab_min_str", tab_min_str );
 
     cf.update( "show_tab_icon", show_tab_icon );
+
+    cf.update( "switchtab_wheel", switchtab_wheel );
+
+    cf.update( "newtab_pos", newtab_pos );
+    cf.update( "opentab_pos", opentab_pos );
+
+    cf.update( "boardnexttab_pos", boardnexttab_pos );
+
     cf.update( "show_post_mark", show_post_mark );
 
     cf.update( "flat_button", flat_button );
@@ -919,6 +965,10 @@ void ConfigItems::set_fonts( JDLIB::ConfLoader& cf )
     // ポップアップのフォント
     fontname[ FONT_POPUP ] = cf.get_option_str( "fontname_popup", defaultfont + " " + std::string( CONF_FONTSIZE_POPUP ) );
 
+    // AA(スレビュー)のフォント
+    fontname[ FONT_AA ] = cf.get_option_str( "fontname_aa", fontname[ FONT_MAIN ] );
+    aafont_enabled = ( fontname[ FONT_MAIN ] != fontname[ FONT_AA ] );
+
     // スレ一覧のフォント
     fontname[ FONT_BBS ] = cf.get_option_str( "fontname_bbs", defaultfont + " " + std::string( CONF_FONTSIZE_TREE ) );
 
@@ -970,13 +1020,22 @@ void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
     // ハイライトの文字色
     str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option_str( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT, 13 );
 
-    // リンク(通常)の文字色
+    // 通常のリンクの文字色
     str_color[ COLOR_CHAR_LINK ] = cf.get_option_str( "cl_char_link", CONF_COLOR_CHAR_LINK, 13 );
 
-    // リンク(複数)の文字色
+    // 複数発言したIDの文字色
+    str_color[ COLOR_CHAR_LINK_ID_LOW ] = cf.get_option_str( "cl_char_link_id_low", CONF_COLOR_CHAR_LINK_ID_LOW, 13 );
+
+    // 多く発言したIDの文字色
+    str_color[ COLOR_CHAR_LINK_ID_HIGH ] = cf.get_option_str( "cl_char_link_id_high", CONF_COLOR_CHAR_LINK_ID_HIGH, 13 );
+
+    // 参照されていないレス番号の文字色
+    str_color[ COLOR_CHAR_LINK_RES ] = cf.get_option_str( "cl_char_link_res", CONF_COLOR_CHAR_LINK_RES, 13 );
+
+    // 他のレスから参照されたレス番号の文字色
     str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option_str( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW, 13 );
 
-    // リンク(多数)の文字色
+    // 参照された数が多いレス番号の文字色
     str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option_str( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH, 13 );
 
     // メッセージビューの文字色
