@@ -106,6 +106,10 @@ const int CONFIG::get_tree_level_indent(){ return get_confitem()->tree_level_ind
 // カテゴリを開いたときにツリービューをスクロールする
 const bool CONFIG::get_scroll_tree(){ return get_confitem()->scroll_tree; }
 
+// ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
+const int CONFIG::get_select_item_sync(){ return get_confitem()->select_item_sync; }
+void CONFIG::set_select_item_sync( const int sync ){ get_confitem()->select_item_sync = sync; }
+
 const int CONFIG::get_view_margin(){ return get_confitem()->view_margin; }
 
 // スクロールバーを左に配置
@@ -127,6 +131,8 @@ void CONFIG::set_fontname( const int id, const std::string& fontname )
 
 void CONFIG::reset_fonts(){ get_confitem()->reset_fonts(); }
 
+const bool CONFIG::get_aafont_enabled(){ return get_confitem()->aafont_enabled; }
+
 
 const std::string CONFIG::get_ref_prefix(){ return get_confitem()->ref_prefix + get_confitem()->ref_prefix_space_str; }
 const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
@@ -137,7 +143,7 @@ const std::string CONFIG::get_regex_res_aa(){
     int size = str.size();
 
     // ダブルクオートの削除
-    if( size > 2 && str[ 0 ] == '"' && str[ size - 1 ] == '"' ){
+    if( size >= 2 && str[ 0 ] == '"' && str[ size - 1 ] == '"' ){
         str = str.substr( 1, size - 2 );
     }
     return str;
@@ -229,6 +235,9 @@ const std::string& CONFIG::get_cookie_hap_bbspink(){ return get_confitem()->cook
 void CONFIG::set_cookie_hap( const std::string& cookie_hap ){ get_confitem()->cookie_hap = cookie_hap; }
 void CONFIG::set_cookie_hap_bbspink( const std::string& cookie_hap ){ get_confitem()->cookie_hap_bbspink = cookie_hap; }
 
+// 2chの過去ログ取得時にofflaw2を使用する
+const bool CONFIG::get_use_offlaw2_2ch(){ return get_confitem()->use_offlaw2_2ch; }
+
 const std::string& CONFIG::get_command_openurl() { return get_confitem()->command_openurl; }
 void CONFIG::set_command_openurl( const std::string& command ){ get_confitem()->command_openurl = command; }
 
@@ -437,9 +446,12 @@ const bool CONFIG::get_show_tab_icon(){ return get_confitem()->show_tab_icon; }
 // タブ上でマウスホイールを回転してタブを切り替える
 const bool CONFIG::get_switchtab_wheel(){ return get_confitem()->switchtab_wheel; }
 
-// ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+// 他のビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
 const int CONFIG::get_newtab_pos(){  return get_confitem()->newtab_pos; }
 
+// ツリービューで選択したビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+const int CONFIG::get_opentab_pos(){  return get_confitem()->opentab_pos; }
+
 // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
 const int CONFIG::get_boardnexttab_pos(){  return get_confitem()->boardnexttab_pos; }
 
@@ -559,8 +571,9 @@ void CONFIG::set_check_favorite_dup( const int check ){ get_confitem()->check_fa
 // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
 const int CONFIG::get_show_favorite_select_diag(){ return get_confitem()->show_favorite_select_diag; }
 
-// Ctrl+qでウィンドウを閉じない
+// Ctrl+qでウィンドウを閉じない ( 2.8.6以前と互換性を保つため残す )
 const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
+void CONFIG::set_disable_close( const bool disable ){ get_confitem()->disable_close = disable; }
 
 // メニューバーを非表示にした時にダイアログを表示
 const bool CONFIG::get_show_hide_menubar_diag(){ return get_confitem()->show_hide_menubar_diag; }
@@ -588,7 +601,6 @@ void CONFIG::set_show_diag_fifo_error( const bool set ){ get_confitem()->show_di
 // 指定した分ごとにセッションを自動保存 (0: 保存しない)
 const int CONFIG::get_save_session(){ return get_confitem()->save_session; }
 
-
 #ifdef HAVE_MIGEMO_H
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
 #endif
