@@ -25,6 +25,7 @@ enum
 {
     MODE_NORMAL = 0,
     MODE_OFFLAW,
+    MODE_OFFLAW2,
     MODE_KAKO_GZ,
     MODE_KAKO
 };
@@ -54,6 +55,39 @@ NodeTree2ch::~NodeTree2ch()
 }
 
 
+//
+// キャッシュに保存する前の前処理
+//
+// 先頭にrawモードのステータスが入っていたら取り除く
+//
+char* NodeTree2ch::process_raw_lines( char* rawlines )
+{
+    char* pos = rawlines;
+
+    if( m_mode == MODE_OFFLAW ){
+        // rokka独自のステータスが入っている
+
+        int status = 0;
+        if( strncmp( pos, "Success", 7 ) == 0 ) status = 1;
+        if( strncmp( pos, "Error", 5 ) == 0 ) status = 2;
+
+#ifdef _DEBUG
+        std::cout << "NodeTree2ch::process_raw_lines : raw mode status = " << status << std::endl;
+#endif
+
+        if( status != 0 ){
+            pos = skip_status_line( pos, status );
+        }
+    }
+
+    else {
+        pos = NodeTree2chCompati::process_raw_lines( rawlines );
+    }
+
+    return pos;
+}
+
+
 //
 // ロード用データ作成
 //
@@ -65,23 +99,60 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
 #endif
 
     data.url = std::string();
+    data.byte_readfrom = 0;
 
-    //offlaw 使用
+    //rokka使用 (旧offlawは廃止)
     if( m_mode == MODE_OFFLAW ){
 
         JDLIB::Regex regex;
-        if( ! regex.exec( "(http://[^/]*)(/.*)/dat(/.*)\\.dat$", m_org_url ) ) return;
+        const size_t offset = 0;
+        const bool icase = false;
+        const bool newline = true;
+        const bool usemigemo = false;
+        const bool wchar = false;
 
+        if( ! regex.exec( "(http://)([^/\\.]+)(\\.[^/]+)(/.*)/dat(/.*)\\.dat$", m_org_url, offset, icase, newline, usemigemo, wchar ) ) return;
+
+        // http://rokka(.2ch.net|.bbspink.com)/<SERVER NAME>/<BOARD NAME>/<DAT NUMBER>/<OPTIONS>?sid=<SID>
         std::ostringstream ss;
-        ss << regex.str( 1 ) << "/test/offlaw.cgi" << regex.str( 2 ) << regex.str( 3 )
-           << "/?raw=." << get_lng_dat();
+        ss << regex.str( 1 ) << "rokka" << regex.str( 3 ) << "/" << regex.str( 2 )
+           << regex.str( 4 ) << regex.str( 5 );
 
         std::string sid = CORE::get_login2ch()->get_sessionid();
-        ss << "&sid=" << MISC::url_encode( sid.c_str(), sid.length() );
+        ss << "/?sid=" << MISC::url_encode( sid.c_str(), sid.length() );
 
-        // レジュームは無し
-        set_resume( false );
-        data.byte_readfrom = 0;
+        // レジューム設定
+        // レジュームを有りにして、サーバが range を無視して送ってきた場合と同じ処理をする
+        if( get_lng_dat() ) {
+            set_resume( true );
+        }
+        else set_resume( false );
+
+        data.url = ss.str();
+    }
+
+    //offlaw2 使用
+    else if( m_mode == MODE_OFFLAW2 ){
+
+        JDLIB::Regex regex;
+        const size_t offset = 0;
+        const bool icase = false;
+        const bool newline = true;
+        const bool usemigemo = false;
+        const bool wchar = false;
+
+        if( ! regex.exec( "(http://[^/]*)/(.*)/dat/(.*)\\.dat$", m_org_url, offset, icase, newline, usemigemo, wchar ) ) return;
+
+        std::ostringstream ss;
+        ss << regex.str( 1 ) << "/test/offlaw2.so?shiro=kuma&sid=ERROR&bbs=" << regex.str( 2 )
+           << "&key=" << regex.str( 3 );
+
+        // レジューム設定
+        // レジュームを有りにして、サーバが range を無視して送ってきた場合と同じ処理をする
+        if( get_lng_dat() ) {
+            set_resume( true );
+        }
+        else set_resume( false );
 
         data.url = ss.str();
     }
@@ -90,7 +161,13 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
     else if( m_mode == MODE_KAKO_GZ || m_mode == MODE_KAKO ){
 
         JDLIB::Regex regex;
-        if( ! regex.exec( "(http://[^/]*)(/.*)/dat(/.*)\\.dat$", m_org_url ) ) return;
+        const size_t offset = 0;
+        const bool icase = false;
+        const bool newline = true;
+        const bool usemigemo = false;
+        const bool wchar = false;
+
+        if( ! regex.exec( "(http://[^/]*)(/.*)/dat(/.*)\\.dat$", m_org_url, offset, icase, newline, usemigemo, wchar ) ) return;
         const int id = atoi( regex.str( 3 ).c_str() + 1 );
 
         std::ostringstream ss;
@@ -106,7 +183,6 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
 
         // レジュームは無し
         set_resume( false );
-        data.byte_readfrom = 0;
 
         data.url = ss.str();
     }
@@ -114,8 +190,6 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
     // 普通の読み込み
     else{
 
-        data.url = get_url();
-
         // レジューム設定
         // 1byte前からレジュームして '\n' が返ってこなかったらあぼーんがあったってこと
         if( get_lng_dat() ) {
@@ -123,6 +197,8 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
             set_resume( true );
         }
         else set_resume( false );
+
+        data.url = get_url();
     }
 
 #ifdef _DEBUG    
@@ -132,6 +208,10 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
 
     data.agent = DBTREE::get_agent( get_url() );
 
+#ifdef _DEBUG
+    std::cout << "agent = " << data.agent << std::endl;
+#endif
+
     data.host_proxy = DBTREE::get_proxy_host( get_url() );
     data.port_proxy = DBTREE::get_proxy_port( get_url() );
     data.basicauth_proxy = DBTREE::get_proxy_basicauth( get_url() );
@@ -156,7 +236,10 @@ void NodeTree2ch::receive_finish()
     // 更新チェックではない、オンラインの場合は offlaw や 過去ログ倉庫から取得出来るか試みる
     if( ! is_checking_update()
         && SESSION::is_online()
-        && ( get_code() == HTTP_REDIRECT || get_code() == HTTP_NOT_FOUND )
+        && ( get_code() == HTTP_REDIRECT || get_code() == HTTP_MOVED_PERM || get_code() == HTTP_NOT_FOUND
+             || ( ( m_mode == MODE_OFFLAW || m_mode == MODE_OFFLAW2 )
+                     && ! get_ext_err().empty() ) // rokka or offlaw2 読み込み失敗
+            )
         ){
 
 /*
@@ -189,14 +272,20 @@ void NodeTree2ch::receive_finish()
 
   (※)ただし 2008年1月1日以降に立てられたスレは除く
 
+  (注) 古すぎる(2000年頃)のdatは形式が違う(<>ではなくて,で区切られている)ので読み込みに失敗する
+
 */
 
-        // ログインしている場合は offlaw.cgi 経由で旧URLで再取得
+        // ログインしている場合は rokka 経由で旧URLで再取得
         if( m_mode == MODE_NORMAL && CORE::get_login2ch()->login_now() ) m_mode = MODE_OFFLAW;
 
+        // offlaw2.so 経由で再取得 ( bbspink を除く )
+        else if( m_mode == MODE_NORMAL && CONFIG::get_use_offlaw2_2ch()
+                && get_url().find( ".bbspink.com" ) == std::string::npos ) m_mode = MODE_OFFLAW2;
+
         // 過去ログ倉庫(gz圧縮)
         // ただし 2008年1月1日以降に立てられたスレは除く
-        else if( m_mode == MODE_NORMAL && m_since_time < 1199113200 ) m_mode = MODE_KAKO_GZ;
+        else if( ( m_mode == MODE_NORMAL || m_mode == MODE_OFFLAW ) && m_since_time < 1199113200 ) m_mode = MODE_KAKO_GZ;
 
         // 過去ログ倉庫
         else if( m_mode == MODE_KAKO_GZ ) m_mode = MODE_KAKO;
