@@ -7,6 +7,7 @@
 
 #include "config/globalconf.h"
 
+#include "environment.h"
 #include "global.h"
 #include "session.h"
 #include "dndmanager.h"
@@ -63,9 +64,7 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
       m_vbox_view( NULL )
 {
     // ステータスバー
-#if GTKMMVER <= 240
-    if( need_mginfo ) m_statbar.pack_start( m_mginfo );
-#else
+#if GTKMM_CHECK_VERSION(2,5,0)
     m_label_stat.set_size_request( 0, -1 );
     m_label_stat.set_alignment( Gtk::ALIGN_LEFT );
     m_label_stat.set_selectable( true );
@@ -75,10 +74,16 @@ JDWindow::JDWindow( const bool fold_when_focusout, const bool need_mginfo )
     m_label_stat_ebox.set_visible_window( false );
 
     m_statbar.pack_start( m_label_stat_ebox );
-    if( need_mginfo ) m_statbar.pack_start( m_mginfo, Gtk::PACK_SHRINK );
+    if( need_mginfo ){
+        m_mginfo_ebox.add( m_mginfo );
+        m_mginfo_ebox.set_visible_window( false );
+        m_statbar.pack_start( m_mginfo_ebox, Gtk::PACK_SHRINK );
+    }
 
     m_mginfo.set_width_chars( MGINFO_CHARS );
     m_mginfo.set_alignment( Gtk::ALIGN_LEFT );
+#else
+    if( need_mginfo ) m_statbar.pack_start( m_mginfo );
 #endif
 
     m_statbar.show_all_children();
@@ -162,9 +167,9 @@ bool JDWindow::slot_idle()
                 m_mode = JDWIN_UNGRAB;
                 m_counter = 0;
             }
-
-            CORE::core_set_command( "window_boot_fin" );
         }
+
+        CORE::core_set_command( "window_boot_fin" );
     }
 
     return false;
@@ -184,7 +189,7 @@ void JDWindow::clock_in()
 
             waitcount = FOCUS_TIME / TIMER_TIMEOUT;
             ++m_counter;
-            if( m_counter > waitcount && ! ( m_counter % waitcount ) ){ 
+            if( m_counter > waitcount && ! ( m_counter % waitcount ) ){
 
                 if( get_height() < get_height_win() ) resize( get_width_win(), get_height_win() );
                 else{
@@ -202,7 +207,7 @@ void JDWindow::clock_in()
         else if( m_mode == JDWIN_UNGRAB ){
 
             ++m_counter;
-            if( m_counter > UNGRAB_TIME / TIMER_TIMEOUT ){ 
+            if( m_counter > UNGRAB_TIME / TIMER_TIMEOUT ){
 #ifdef _DEBUG
                 std::cout << "JDWindow::clock_in ungrab\n";
 #endif
@@ -212,7 +217,7 @@ void JDWindow::clock_in()
                 set_transient( false );
                 get_window()->lower();
                 set_transient( true );
-                
+
                 CORE::core_set_command( "restore_focus", "", "present" );
                 m_mode = JDWIN_FOLD;
             }
@@ -222,7 +227,7 @@ void JDWindow::clock_in()
         // メインウィンドウと画像ウィンドウが同時にフォーカスアウトしたら
         // 一時的に transient 指定を外す。メインウィンドウがフォーカスインしたときに
         // Admin::focus_out() で transient 指定を戻す
-        if( SESSION::get_wm() == SESSION::WM_GNOME
+        if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_GNOME
             && ! SESSION::is_iconified_win_main() // メインウィンドウが最小化しているときに transient を外すとウィンドウが表示されなくなる
             && ! SESSION::is_focus_win_main() && ! is_focus_win() ){
 
@@ -256,9 +261,23 @@ void JDWindow::maximize_win()
 }
 
 
+void JDWindow::unmaximize_win()
+{
+    set_maximized_win( false );
+    unmaximize();
+}
+
+
+void JDWindow::iconify_win()
+{
+    set_iconified_win( true );
+    iconify();
+}
+
+
 //
 // ウィンドウ移動
-// 
+//
 void JDWindow::move_win( const int x, const int y )
 {
     if( ! CONFIG::get_manage_winpos() ) return;
@@ -362,11 +381,11 @@ void JDWindow::set_status( const std::string& stat )
 
     m_status = stat;
 
-#if GTKMMVER <= 240
-    m_statbar.push( stat );
-#else
+#if GTKMM_CHECK_VERSION(2,5,0)
     m_label_stat.set_text( stat );
     m_tooltip.set_tip( m_label_stat_ebox, stat );
+#else
+    m_statbar.push( stat );
 #endif
 }
 
@@ -379,20 +398,20 @@ void JDWindow::set_status_temporary( const std::string& stat )
 {
     if( stat == m_status ) return;
 
-#if GTKMMVER <= 240
-    m_statbar.push( stat );
-#else
+#if GTKMM_CHECK_VERSION(2,5,0)
     m_label_stat.set_text( stat );
+#else
+    m_statbar.push( stat );
 #endif
 }
 
 // 一時的に変えたステータスバーの表示を戻す
 void JDWindow::restore_status()
 {
-#if GTKMMVER <= 240
-    m_statbar.push( m_status );
-#else
+#if GTKMM_CHECK_VERSION(2,5,0)
     m_label_stat.set_text( m_status );
+#else
+    m_statbar.push( m_status );
 #endif
 }
 
@@ -404,6 +423,42 @@ void JDWindow::set_mginfo( const std::string& mginfo )
 }
 
 
+// ステータスの色を変える
+void JDWindow::set_status_color( const std::string& color )
+{
+#if GTKMM_CHECK_VERSION(2,5,0)
+
+#ifdef _DEBUG
+    std::cout << "JDWindow::set_status_color " << color << std::endl;
+#endif
+
+    if( color.empty() ){
+
+        if( m_label_stat_ebox.get_visible_window() ){
+            m_label_stat.unset_fg( Gtk::STATE_NORMAL );
+            m_mginfo.unset_fg( Gtk::STATE_NORMAL );
+
+            m_label_stat_ebox.set_visible_window( false );
+            m_mginfo_ebox.set_visible_window( false );
+        }
+    }
+    else{
+
+        m_label_stat.modify_fg( Gtk::STATE_NORMAL, Gdk::Color( "white" ) );
+        m_mginfo.modify_fg( Gtk::STATE_NORMAL, Gdk::Color( "white" ) );
+
+        m_label_stat_ebox.set_visible_window( true );
+        m_label_stat_ebox.modify_bg( Gtk::STATE_NORMAL, Gdk::Color( color ) );
+        m_label_stat_ebox.modify_bg( Gtk::STATE_ACTIVE, Gdk::Color( color ) );
+
+        m_mginfo_ebox.set_visible_window( true );
+        m_mginfo_ebox.modify_bg( Gtk::STATE_NORMAL, Gdk::Color( color ) );
+        m_mginfo_ebox.modify_bg( Gtk::STATE_ACTIVE, Gdk::Color( color ) );
+    }
+#endif
+}
+
+
 // メインウィンドウに対して transient 設定
 void JDWindow::set_transient( bool set )
 {
@@ -443,7 +498,7 @@ void JDWindow::set_enable_fold( bool enable )
         // XFCE 環境の場合はここでpresent()しておかないとフォーカスが外れる
         if( m_mode == JDWIN_NORMAL && m_enable_fold ){
 
-            if( SESSION::get_wm() == SESSION::WM_KDE ) switch_admin();
+            if( ENVIRONMENT::get_wm() == ENVIRONMENT::WM_KDE ) switch_admin();
             else present();
         }
     }
@@ -605,13 +660,15 @@ bool JDWindow::on_delete_event( GdkEventAny* event )
 // 最大、最小化
 bool JDWindow::on_window_state_event( GdkEventWindowState* event )
 {
-    bool maximized = event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED;
-    bool iconified = event->new_window_state & GDK_WINDOW_STATE_ICONIFIED;
+    const bool maximized = event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED;
+    const bool iconified = event->new_window_state & GDK_WINDOW_STATE_ICONIFIED;
+    const bool fullscreen = event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN;
 
 #ifdef _DEBUG
-    std::cout << "JDWindow::on_window_state_event : " 
+    std::cout << "JDWindow::on_window_state_event : "
               << "maximized = " << is_maximized_win() << " -> " << maximized
-              << " / iconified = " << is_iconified_win() << " -> " << iconified << std::endl;
+              << " / iconified = " << is_iconified_win() << " -> " << iconified
+              << " / full = " << is_full_win() << " -> " << fullscreen << std::endl;
 #endif
 
     if( ! m_boot ){
@@ -638,9 +695,15 @@ bool JDWindow::on_window_state_event( GdkEventWindowState* event )
             else m_mode = JDWIN_UNMAX;
         }
 
+        // 通常 -> 全画面
+        else if( ! is_full_win() && fullscreen ) set_full_win( true );
+
+        // 全画面 -> 通常
+        else if( is_full_win() && ! fullscreen ) set_full_win( false );
+
 #ifdef _DEBUG
         std::cout << " mode = " << m_mode << std::endl;
-#endif     
+#endif
     }
 
     set_maximized_win( maximized );
@@ -675,7 +738,7 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
         else if( m_mode == JDWIN_UNMAX_FOLD ) m_mode = JDWIN_FOLD;
 
         // 最大、最小化しているときは除く
-        else if( ! is_maximized_win() && ! is_iconified_win() ){
+        else if( ! is_maximized_win() && ! is_iconified_win() && ! is_full_win() ){
 
             set_win_pos();
 
@@ -689,12 +752,12 @@ bool JDWindow::on_configure_event( GdkEventConfigure* event )
         }
 
 #ifdef _DEBUG
-    std::cout << "configure fin --> mode = " << m_mode << " show = " << is_shown_win() 
+    std::cout << "configure fin --> mode = " << m_mode << " show = " << is_shown_win()
               << " maximized = " << is_maximized_win()
               << " iconified = " << is_iconified_win()
               << " x = " << get_x_win() << " y = " << get_y_win()
               << " w = " << get_width_win() << " height = " << get_height_win() << std::endl;
-#endif     
+#endif
     }
 
     return Gtk::Window::on_configure_event( event );
